@@ -25,8 +25,8 @@ def validate_field_len(field, field_bin_value, length,field_name):
     if not field_name:
         field_name = 'immediate' if length == 16 else 'address'
     if len(field_bin_value) > length:
-        FieldLengthError_msg = field+' = '+field_bin_value
-        FieldLengthError_msg += '\ntoo long! field '+field_name+' length is '
+        FieldLengthError_msg = 'ERROR:'+field+' = '+field_bin_value
+        FieldLengthError_msg += '\ntoo long! field "'+field_name+'" length is '
         FieldLengthError_msg += str(len(field_bin_value)) +', max length is '+str(length)
         raise FieldLengthError(FieldLengthError_msg)
 
